@@ -1,5 +1,6 @@
 
 from django.db import models
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
 
@@ -22,6 +23,9 @@ class FlatPage(models.Model):
         help_text=_("If this is checked, only logged-in "
                     "users will be able to view the page."), default=False)
 
+    def get_absolute_url(self):
+        return reverse_lazy('flatpages:page', kwargs={'url': self.url})
+
     class Meta:
         verbose_name = _('Flat page')
         verbose_name_plural = _('Flat pages')
